@@ -151,8 +151,13 @@ def plot(data, args, label):
         if args["y_limits"]:
             fig.set_y_limits(min_=args["y_limits"][0], max_=args["y_limits"][1])
         else:
-            fig.set_y_limits(min_=np.min(data[:, 1]), max_=np.max(data[:, 1]))
-
+            try:
+                fig.set_y_limits(min_=np.min(data[:, 1:]), max_=np.max(data[:, 1:]))
+            except ValueError:
+                min_max = np.mean(data[:, 1:])
+                fig.set_y_limits(
+                    min_=min_max - min_max * 0.1, max_=min_max + min_max * 0.1
+                )
         if args["color"]:
             fig.color_mode = "rgb"
 
@@ -316,7 +321,7 @@ def get_args(opt=None):
         "-c", "--color", help=("enable RGB colorized the plots"), action="store_true"
     )
     parser.add_argument(
-        "-l", "--legend", help=("enable the legend of the plots"), action="store_false"
+        "-l", "--legend", help=("disable the legend of the plots"), action="store_false"
     )
     parser.add_argument(
         "-v",
